Aggregator.App.index\_query.RetrieveResponse.\_\_init\_\_
=========================================================

.. currentmodule:: Aggregator.App.index_query

.. automethod:: RetrieveResponse.__init__